@@ -1,5 +1,8 @@
+
 test_that('BOIN recommendations match published example.', {
 
+  # p.25 of Han, Pan, Zhang, Liu & Yuan (2019)
+
   num_doses <- 5
   target <- 0.3
   boin_fitter <- get_boin(num_doses = num_doses, target = target)
@@ -117,6 +120,10 @@ test_that('boin_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -134,6 +141,9 @@ test_that('boin_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -145,6 +155,12 @@ test_that('boin_selector supports correct interface.', {
   expect_error(prob_tox_samples(x))
   expect_error(prob_tox_samples(x, tall = TRUE))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
   # Example 2, using trivial outcome string
   x <- fit(model_fitter, '')
@@ -208,6 +224,10 @@ test_that('boin_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -224,6 +244,9 @@ test_that('boin_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -235,6 +258,12 @@ test_that('boin_selector supports correct interface.', {
   expect_error(prob_tox_samples(x))
   expect_error(prob_tox_samples(x, tall = TRUE))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
   # Example 3, using tibble
   outcomes <- tibble(
@@ -302,6 +331,10 @@ test_that('boin_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -319,6 +352,9 @@ test_that('boin_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -330,6 +366,12 @@ test_that('boin_selector supports correct interface.', {
   expect_error(prob_tox_samples(x))
   expect_error(prob_tox_samples(x, tall = TRUE))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 })
 
 
@@ -350,21 +392,33 @@ test_that('BOIN advises stopping when indicated', {
   x <- fit(boin_fitter, '1N')
   expect_equal(recommended_dose(x), 2)
   expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
 
   # Design should de-escalate
   x <- fit(boin_fitter, '1N 2TN')
   expect_equal(recommended_dose(x), 1)
   expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
 
   # Design should not yet stop
   x <- fit(boin_fitter, '1N 2TN 1TT')
   expect_equal(recommended_dose(x), 1)
   expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
 
   # Now design should stop
   x <- fit(boin_fitter, '1N 2TN 1TTT')
   expect_true(is.na(recommended_dose(x)))
   expect_false(continue(x))
+  expect_equal(dose_admissible(x), rep(FALSE, num_doses(x)))
+
+  # If those 3 in 4 DLTs occurred at a higher dose, trial should continue but
+  # toxic dose and those doses above should be inadmissible
+  x <- fit(boin_fitter, '1N 4TTTT')
+  expect_equal(recommended_dose(x), 3)
+  expect_true(continue(x))
+  expect_equal(dose_admissible(x), c(TRUE, TRUE, TRUE, FALSE, FALSE))
+
 })
 
 
@@ -385,21 +439,32 @@ test_that('BOIN stopping rule can be turned off.', {
   x <- fit(boin_fitter, '1N')
   expect_equal(recommended_dose(x), 2)
   expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
 
   # Design should de-escalate
   x <- fit(boin_fitter, '1N 2TN')
   expect_equal(recommended_dose(x), 1)
   expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
 
   # Design should not stop here
   x <- fit(boin_fitter, '1N 2TN 1TT')
   expect_equal(recommended_dose(x), 1)
   expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
 
   # Design should not stop here either
   x <- fit(boin_fitter, '1N 2TN 1TTT')
   expect_equal(recommended_dose(x), 1)
   expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
+
+  # If those 3 in 4 DLTs occurred at a higher dose, the trial should still
+  # continue and all doses should be admissible
+  x <- fit(boin_fitter, '1N 4TTTT')
+  expect_equal(recommended_dose(x), 3)
+  expect_true(continue(x))
+  expect_equal(dose_admissible(x), rep(TRUE, num_doses(x)))
 
   # Compare to tests above, this shows that the stopping rule has been disabled.
 })
