@@ -92,6 +92,10 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -103,11 +107,19 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.numeric(empiric_tox_rate(x)))
   expect_equal(length(empiric_tox_rate(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.logical(supports_sampling(x)))
 
   expect_error(prob_tox_samples(x))
   expect_error(prob_tox_samples(x, tall = TRUE))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
 
 
   # Example 2, using trivial outcome string
@@ -171,6 +183,10 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -181,11 +197,19 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.numeric(empiric_tox_rate(x)))
   expect_equal(length(empiric_tox_rate(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.logical(supports_sampling(x)))
 
   expect_error(prob_tox_samples(x))
   expect_error(prob_tox_samples(x, tall = TRUE))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
 
 
   # Example 3, using tibble of outcomes
@@ -254,6 +278,10 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.na(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -265,11 +293,19 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.numeric(empiric_tox_rate(x)))
   expect_equal(length(empiric_tox_rate(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.logical(supports_sampling(x)))
 
   expect_error(prob_tox_samples(x))
   expect_error(prob_tox_samples(x, tall = TRUE))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
 
 
 
@@ -322,6 +358,10 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.na(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5, 0.5))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -333,11 +373,20 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.numeric(empiric_tox_rate(x)))
   expect_equal(length(empiric_tox_rate(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.logical(supports_sampling(x)))
 
   expect_error(prob_tox_samples(x))
   expect_error(prob_tox_samples(x, tall = TRUE))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 })
 
 
