@@ -1,5 +1,5 @@
 
-test_that('stop_when_too_toxic_selector does what it should', {
+test_that('stop_when_too_toxic_selector does what it should.', {
 
   skeleton <- c(0.05, 0.1, 0.25, 0.4, 0.6)
   target <- 0.25
@@ -14,12 +14,15 @@ test_that('stop_when_too_toxic_selector does what it should', {
   prob_too_toxic <- prob_tox_exceeds(fit, target + 0.1)
   expect_equal(recommended_dose(fit), fit$parent$dfcrm_fit$mtd)
   expect_equal(continue(fit), prob_too_toxic[1] < 0.8)
+  expect_equal(dose_admissible(fit), prob_too_toxic < 0.8)
+
 
   # But the extra tox event should tip the scale
   set.seed(123)
   fit <- model1 %>% fit('2NTN 1TTT')
   prob_too_toxic <- prob_tox_exceeds(fit, target + 0.1)
   expect_equal(continue(fit), prob_too_toxic[1] < 0.8)
+  expect_equal(dose_admissible(fit), prob_too_toxic < 0.8)
 })
 
 test_that('stop_when_too_toxic_selector supports correct interface.', {
@@ -94,6 +97,10 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -111,6 +118,9 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -122,6 +132,12 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.data.frame(prob_tox_samples(x)))
   expect_true(is.data.frame(prob_tox_samples(x, tall = TRUE)))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
 
   # Example 2, using trivial outcome string
@@ -186,6 +202,10 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -202,6 +222,9 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -213,6 +236,12 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.data.frame(prob_tox_samples(x)))
   expect_true(is.data.frame(prob_tox_samples(x, tall = TRUE)))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
 
   # Example 3, using tibble of outcomes
@@ -284,6 +313,10 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -301,6 +334,9 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -312,4 +348,10 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(is.data.frame(prob_tox_samples(x)))
   expect_true(is.data.frame(prob_tox_samples(x, tall = TRUE)))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 })
